.. burp_reports documentation master file, created by
   sphinx-quickstart on Sat Oct  7 00:27:40 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to burp_reports's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   README
  

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
